package com.thekua.ant.taskdefs.optional.junit;

import junit.framework.AssertionFailedError;
import junit.framework.Test;
import org.apache.tools.ant.BuildException;
import org.apache.tools.ant.taskdefs.optional.junit.JUnitResultFormatter;
import org.apache.tools.ant.taskdefs.optional.junit.JUnitTest;
import org.apache.tools.ant.taskdefs.optional.junit.XMLJUnitResultFormatter;

import java.io.OutputStream;

/**
 * A customer formatter that wraps a normal XML formatter to only report output on test errors or failures. 
 */
public class QuietXMLFormatter implements JUnitResultFormatter {

    private XMLJUnitResultFormatter junitFormatter = new XMLJUnitResultFormatter();
    private boolean errorOrFailed;

    public void startTestSuite(JUnitTest suite) throws BuildException {
        junitFormatter.startTestSuite(suite);
    }

    /**
     * Only write output if the tests failed or errored. The wrapped formatter in Ant 1.6.x does it in this method.
     */
    public void endTestSuite(JUnitTest suite) throws BuildException {
        if (errorOrFailed) {
            junitFormatter.endTestSuite(suite);
        }
    }

    public void setOutput(OutputStream out) {
        junitFormatter.setOutput(out);
    }

    public void setSystemOutput(String out) {
        junitFormatter.setSystemOutput(out);
    }

    public void setSystemError(String err) {
        junitFormatter.setSystemError(err);
    }

    // The following methods are implemented to support Junit 3.4 interface notifications

    public void addError(Test test, Throwable throwable) {
        errorOrFailed = true;
        junitFormatter.addError(test, throwable);
    }

    public void addFailure(Test test, AssertionFailedError assertionFailedError) {
        errorOrFailed = true;
        junitFormatter.addFailure(test, assertionFailedError);
    }

    public void endTest(Test test) {
        junitFormatter.endTest(test);
    }

    public void startTest(Test test) {
        junitFormatter.startTest(test);

    }
}



